@@ -425,6 +425,10 @@ def parse_script_extensions(properties, subpath):
                 prop_name = line.split()[-1]
                 property = properties[munge(prop_name)]
                 property['values'] = {}
+            elif line.startswith('# All code points not explicitly listed for '):
+                prop_name = line.split()[-1]
+                property = properties[munge(prop_name)]
+                property['values'] = {}
             elif not line.startswith('#'):
                 line = line.partition('#')[0]
                 fields = [field.strip() for field in line.split(';')]
@@ -660,6 +664,16 @@ def make_additional_properties(unicode_data):
 
     make_binary_property(properties, ['Posix_XDigit'], posix_xdigit)
 
+    # Make the 'Posix_Space' property.
+    posix_space = make_ranges(0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x20)
+
+    make_binary_property(properties, ['Posix_Space'], posix_space)
+
+    # Make the 'Posix_Word' property.
+    posix_word = posix_alnum | Ranges([(ord('_'), ord('_'))])
+
+    make_binary_property(properties, ['Posix_Word'], posix_word)
+
     # Make the 'Horiz_Space' property.
     horiz_space = make_ranges(0x09, 0x20, 0xA0, 0x1680, 0x180E) | Ranges([(0x2000, 0x200A)]) | make_ranges(0x202F, 0x205F, 0x3000)
 
@@ -789,9 +803,6 @@ def determine_entry_type(iterable):
 
     raise ValueError('cannot determine C type for {}..{}'.format(lower, upper))
 
-def is_binary(property):
-    return sum(1 for val in val_list if val['id'] != 0) == 1
-
 def count_ranges(property):
     count = 0
     default_id = property['values'][munge(property['default'])]['id']
@@ -1764,7 +1775,7 @@ typedef RE_UINT32 (*RE_GetPropertyFunc)(RE_UINT32 codepoint);
         h_file.write('int re_get_full_case_folding(RE_UINT32 codepoint, RE_UINT32* folded);\n')
 
 # The Unicode version.
-UNICODE_VERSION = '15.1.0'
+UNICODE_VERSION = '16.0.0'
 
 this_folder = dirname(__file__)
 
